<?php
declare(strict_types=1);
/**
 * -----------------------------------------
 * @since Version 2.51 - 13.03.2025
 * @version 2.51
 * @link https://www.kontaktformular-script.de/
 * @author Nico Schubert / SchubertMedia
 * @contact E-Mail: info@schubertmedia.de
 *
 * @copyright Das Entfernen des Copyright-Hinweises in diesem Kontaktformular-Skript ist untersagt.
 * @note Eine version ohne Copyright knnen Sie fr einmalig 20,- EUR inkl. 19% MwSt. erwerben.
 * Besuchen Sie hierzu bitte das Bestellformular unter https://www.kontaktformular-script.de/bestellen.php.
 * -----------------------------------------
 */
/**
 * Prft, ob eine E-Mail-Adresse gltig ist.
 *
 * @param string $email Die zu prfende E-Mail-Adresse.
 * @return bool Gibt true zurck, wenn die E-Mail-Adresse gltig ist, andernfalls false.
 */
function check_email(string $email): bool {
  return filter_var($email, FILTER_VALIDATE_EMAIL) !== false;
}

/**
 * Ersetzt deutsche Umlaute und das scharfe S durch entsprechende ASCII-Zeichen.
 *
 * @param string $string Der Eingabestring.
 * @return string Der String mit ersetzten Umlauten.
 */
function clean_umlaute(string $string): string {
  if (function_exists('get_magic_quotes_gpc') && get_magic_quotes_gpc()) {
    $string = stripslashes($string);
  }
  $replacements = [
    "" => "ae", "" => "oe", "" => "ue", "" => "ss",
    "" => "Ae", "" => "Oe", "" => "Ue"
  ];
  return str_replace(array_keys($replacements), array_values($replacements), $string);
}

/**
 * Wandelt ein Array in eine JSON-hnliche Zeichenkette um.
 *
 * @param array $array Das zu konvertierende Array.
 * @return string|false Die JSON-hnliche Zeichenkette oder false, wenn das Array leer ist.
 */
function array_to_json(array $array): string|false {
  if (empty($array)) {
    return false;
  }

  $isAssociative = array_keys($array) !== range(0, count($array) - 1);
  $construct = [];

  foreach ($array as $key => $value) {
    if ($isAssociative) {
      $key = is_numeric($key) ? "key_$key" : addslashes((string)$key);
      $key = '"' . $key . '"';
    }

    if (is_array($value)) {
      $value = array_to_json($value);
    } elseif (!is_numeric($value) || is_string($value)) {
      $value = '"' . addslashes((string)$value) . '"';
    }
    $construct[] = $isAssociative ? "$key: $value" : $value;
  }

  return $isAssociative ? '{ ' . implode(', ', $construct) . ' }' : '[ ' . implode(', ', $construct) . ' ]';
}

/**
 * Behandelt Fehler, die whrend der Ausfhrung des Programms auftreten, und protokolliert sie in einer Log-Datei.
 *
 * @param int $errno Die Fehlernummer.
 * @param string $errstr Die Fehlermeldung.
 * @param string $errfile Der Name der Datei, in der der Fehler aufgetreten ist.
 * @param int $errline Die Zeilennummer, in der der Fehler aufgetreten ist.
 * @return void
 */
function benutzerFehlerHandler(int $errno, string $errstr, string $errfile, int $errline): void {
  global $errors;
  // Die Log-Datei soll im gleichen Verzeichnis abgelegt werden.
  $destination = __DIR__ . '/error_log.txt';
  if (!file_exists($destination)) {
    if (!touch($destination)) {
      echo sprintf($errors['benutzer_fehler'], $errno, $errstr, $errfile, $errline);
      exit();
    }
  }
  $errorMessage = sprintf($errors['benutzer_fehler'], $errno, $errstr, $errfile, $errline);
  echo $errorMessage . "<br>";
  error_log($errorMessage . "\n", 3, $destination);
  if ($errno === E_ERROR) {
    exit();
  }
}