jQuery.noConflict();
(function($) {
  /**
   * -----------------------------------------
   * @since Version 2.51 - 13.03.2025
   * @version 2.51
   * @link https://www.kontaktformular-script.de/
   * @author Nico Schubert / SchubertMedia
   * @contact E-Mail: info@schubertmedia.de
   *
   * @copyright Das Entfernen des Copyright-Hinweises in diesem Kontaktformular-Skript ist untersagt.
   * @note Eine version ohne Copyright knnen Sie fr einmalig 20,- EUR inkl. 19% MwSt. erwerben.
   * Besuchen Sie hierzu bitte das Bestellformular unter https://www.kontaktformular-script.de/bestellen.php.
   * -----------------------------------------
   */

  function load_text() {
    return $.ajax({
      url: "kontakt.php",
      dataType: "json",
      type: "POST",
      data: { ajax: '1' }
    });
  }

  /**
   * Prft, ob die angegebene E-Mail-Adresse gltig ist.
   * @param {string} mail
   * @returns {boolean}
   */
  function checkmail(mail) {
    var regex = new RegExp("^" +
      "(mailto:)?" +
      "([a-zA-Z0-9][a-zA-Z0-9_.-]*|\"([^\\\\\x80-\xff\015\012\"]|\\\\[^\x80-\xff])+\")" +
      "@" +
      "([a-zA-Z0-9][a-zA-Z0-9._-]*\\.)*[a-zA-Z0-9][a-zA-Z0-9._-]*\\.[a-zA-Z]{2,6}" +
      "$");
    return regex.test(mail);
  }

  // Delegierte Ereignisbindung: Beim Klick auf ein Element mit der Klasse "error-message" wird dieses sanft ausgeblendet und entfernt.
  $(document).on('click', '.error-message', function() {
    $(this).fadeOut('slow', function() {
      $(this).remove();
    });
  });

  $(function() {
    load_text().done(function(request_data) {

      // Gemeinsame Funktion zur Behandlung von Validierungsfehlern
      function handleError($field, message) {
        if (request_data.show_java_alert === '1') {
          alert(message);
        }
        if ($('.error-message').length === 0) {
          // Fehlermeldung einfgen, ohne dabei das gesamte Formular zu verstecken
          $('<span class="error-message">' + message + '</span>')
            .hide()
            .insertBefore('table.table')
            .fadeIn('slow');
        }
        // Dem Feld eine eigene Fehlerklasse hinzufgen, ohne den Input zu lschen
        $field.addClass('error-field').focus().focusout(function() {
          $(this).removeClass('error-field');
        });
        // Rcksetzen von Lade- und Button-Zustnden
        $('span.loading_aktiv').each(function() {
          $(this).addClass('loading').removeClass('loading_aktiv');
        });
        $('input.submit_button_disabled').each(function() {
          $(this).removeAttr('disabled').removeClass('submit_button_disabled');
        });
      }

      $('form[action="kontakt.php"]').on('submit', function() {
        $('.error-message').remove(); // Entfernt eventuelle bestehende Fehleranzeigen

        // Selektoren cachen, um wiederholte DOM-Zugriffe zu minimieren
        var $vorname   = $('input[name="vorname"]'),
          $nachname  = $('input[name="nachname"]'),
          $email     = $('input[name="email"]'),
          $nachricht = $('textarea[name="nachricht"]'),
          $loesung   = $('input[name="loesung"]');

        if ($vorname.val() === '') {
          handleError($vorname, request_data.vorname);
          return false;
        }
        if ($nachname.val() === '') {
          handleError($nachname, request_data.nachname);
          return false;
        }
        if ($email.val() === '') {
          handleError($email, request_data.email);
          return false;
        }
        if (!checkmail($email.val())) {
          handleError($email, request_data.email);
          return false;
        }
        if ($nachricht.val() === '') {
          handleError($nachricht, request_data.nachricht);
          return false;
        }
        if ($loesung.length && $loesung.val() === '') {
          handleError($loesung, request_data.bestaestigungs_code);
          return false;
        }
      });
    });
  });
})(jQuery);
